Thank you for your contribution to the **license_scanner** package.
Before submitting/accepting this Pull Request, please make sure:

## Contributor of code

- [ ] Functions are named based on [Python naming conventions](https://visualgit.readthedocs.io/en/latest/pages/naming_convention.html)
- [ ] Explain how to run the code `(docstring)`
- [ ] Function is tested
- [ ] All needed package are in [pyproject.toml](pyproject.toml)
- [ ] Version number is updated
- [ ] `HISTORY.rst` is updated
- [ ] New feature is added to `README.md`
- [ ] New license is added to `README.md` subsection `Supported licenses`

## Reviewer

- [ ] Functions are named based on [Python naming conventions](https://visualgit.readthedocs.io/en/latest/pages/naming_convention.html)
- [ ] Explain how to run the code `(docstring)`
- [ ] Function is tested
- [ ] All needed package are in [pyproject.toml](pyproject.toml)
- [ ] Version number is updated
- [ ] `HISTORY.rst` is updated
- [ ] New feature is added to `README.md`
- [ ] New license is added to `README.md` subsection `Supported licenses`
